/*
 * Copyright 2012-2017 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.spring.initializr.metadata;

import org.junit.Test;

import static org.junit.Assert.assertEquals;

/**
 * @author Stephane Nicoll
 */
public class TextCapabilityTests {

	@Test
	public void mergeValue() {
		TextCapability capability = new TextCapability("foo");
		capability.setContent("1234");
		TextCapability another = new TextCapability("foo");
		another.setContent("4567");
		capability.merge(another);
		assertEquals("foo", capability.getId());
		assertEquals(ServiceCapabilityType.TEXT, capability.getType());
		assertEquals("4567", capability.getContent());
	}

	@Test
	public void mergeTitle() {
		TextCapability capability = new TextCapability("foo", "Foo", "my desc");
		capability.merge(new TextCapability("foo", "AnotherFoo", ""));
		assertEquals("foo", capability.getId());
		assertEquals(ServiceCapabilityType.TEXT, capability.getType());
		assertEquals("AnotherFoo", capability.getTitle());
		assertEquals("my desc", capability.getDescription());
	}

	@Test
	public void mergeDescription() {
		TextCapability capability = new TextCapability("foo", "Foo", "my desc");
		capability.merge(new TextCapability("foo", "", "another desc"));
		assertEquals("foo", capability.getId());
		assertEquals(ServiceCapabilityType.TEXT, capability.getType());
		assertEquals("Foo", capability.getTitle());
		assertEquals("another desc", capability.getDescription());
	}

}
